@@ -1,5 +1,6 @@
 import json
 
+from django.test.utils import override_settings
 from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse, resolve
 from django.test import TestCase
@@ -26,7 +27,7 @@ FOO_RESPONSE = {
     u'success_action_status': u'201',
     u'acl': u'public-read',
     u'key': u'foo/${filename}',
-    u'Content-Type': u'image/jpg'
+    u'Content-Type': u'image/jpeg'
 }
 
 
@@ -52,20 +53,38 @@ class WidgetTest(TestCase):
 
     def test_signing_logged_in(self):
         self.client.login(username='admin', password='admin')
-        data = {'upload_to': 'foo', 'name': 'image.jpg', 'type': 'image/jpg'}
+        data = {'upload_to': 'foo', 'name': 'image.jpg', 'type': 'image/jpeg'}
         response = self.client.post(reverse('s3direct'), data)
         self.assertEqual(response.status_code, 200)
 
     def test_signing_logged_out(self):
-        data = {'upload_to': 'foo', 'name': 'image.jpg', 'type': 'image/jpg'}
+        data = {'upload_to': 'foo', 'name': 'image.jpg', 'type': 'image/jpeg'}
         response = self.client.post(reverse('s3direct'), data)
         self.assertEqual(response.status_code, 403)
 
     def test_signing_fields(self):
         self.client.login(username='admin', password='admin')
-        data = {'upload_to': 'foo', 'name': 'image.jpg', 'type': 'image/jpg'}
+        data = {'upload_to': 'foo', 'name': 'image.jpg', 'type': 'image/jpeg'}
         response = self.client.post(reverse('s3direct'), data)
         response_dict = json.loads(response.content.decode())
         self.assertTrue(u'signature' in response_dict)
         self.assertTrue(u'policy' in response_dict)
         self.assertDictContainsSubset(FOO_RESPONSE, response_dict)
+
+    @override_settings(S3DIRECT_ALLOWED_MIME_TYPES=['image/jpeg'])
+    def test_invalid_type(self):
+        self.client.login(username='admin', password='admin')
+        data = {'upload_to': 'foo', 'name': 'image.jpg', 'type': 'image/png'}
+        response = self.client.post(reverse('s3direct'), data)
+        response_dict = json.loads(response.content.decode())
+        self.assertEqual(response_dict['error'], 'Invalid file type.')
+
+    @override_settings(S3DIRECT_ALLOWED_MIME_TYPES=['image/jpeg'])
+    def test_allowed_type(self):
+        self.client.login(username='admin', password='admin')
+        data = {'upload_to': 'foo', 'name': 'image.jpg', 'type': 'image/jpeg'}
+        response = self.client.post(reverse('s3direct'), data)
+        response_dict = json.loads(response.content.decode())
+        self.assertTrue(u'signature' in response_dict)
+        self.assertTrue(u'policy' in response_dict)
+        self.assertDictContainsSubset(FOO_RESPONSE, response_dict)
\ No newline at end of file
